package org.apache.bcel.classfile;

import java.io.IOException;
import java.io.DataOutputStream;

public class ElementValuePair
{
    static final ElementValuePair[] EMPTY_ARRAY;
    private final ElementValue elementValue;
    private final ConstantPool constantPool;
    private final int elementNameIndex;
    
    public ElementValuePair(final int elementNameIndex, final ElementValue elementValue, final ConstantPool constantPool) {
        this.elementValue = elementValue;
        this.elementNameIndex = elementNameIndex;
        this.constantPool = constantPool;
    }
    
    protected void dump(final DataOutputStream dos) throws IOException {
        dos.writeShort(this.elementNameIndex);
        this.elementValue.dump(dos);
    }
    
    public int getNameIndex() {
        return this.elementNameIndex;
    }
    
    public String getNameString() {
        return this.constantPool.getConstantUtf8(this.elementNameIndex).getBytes();
    }
    
    public final ElementValue getValue() {
        return this.elementValue;
    }
    
    public String toShortString() {
        final StringBuilder result = new StringBuilder();
        result.append(this.getNameString()).append("=").append(this.getValue().toShortString());
        return result.toString();
    }
    
    static {
        EMPTY_ARRAY = new ElementValuePair[0];
    }
}
